@@ -6,6 +6,8 @@ from .misp import MISP
 from .onyphe import Onyphe
 from .otx import OTX
 from .pulsedive import Pulsedive
+from .threatfox import ThreatFox
 from .urlhaus import URLhaus
 from .urlscan import URLscan
 from .virustotal import VirusTotalV2, VirusTotalV3
+from .xforce import XForceExchange
